@@ -6,7 +6,7 @@
   
 #ifndef EOS2_AUTO_CONFIG
 #define  HDFEOSd_BANNER  "@(#)## =================  HDFEOS  ================"
-#if defined(LINUX) || defined(LINUX64) || defined(IA64) || defined(MACINTOSH) || defined(CYGWIN) || defined(MACINTEL)
+#if defined(LINUX) || defined(LINUX64) || defined(IA64) || defined(MACINTOSH) || defined(CYGWIN) || defined(MACINTEL) || defined(SUNOS511X)
 #define  HDFEOSd_HDFEOS_VER  "@(#)## HDFEOS Version: "HDFEOSVERSION1
 #define  HDFEOSd_DATE    "@(#)## Build date: "__DATE__" @ "__TIME__
 #else
