@@ -17,8 +17,8 @@ c
 c     Open the HDF point file, "PointFile.hdf".
 c
 
-	ptfid = ptopen("PointFile_created_with_hadeos_sample_file_writer
-     1_of_HDFEOS2_version_219_or_higher_release.hdf", DFACC_RDWR)
+	ptfid = ptopen("PointFile_created_with_hadeos_sample_file_write"//
+     1"r_of_HDFEOS2_version_219_or_higher_release.hdf", DFACC_RDWR)
 
 	ptid1 = ptattach(ptfid, "Simple Point")
 	ptid2 = ptattach(ptfid, "FixedBuoy Point")
