@@ -18,12 +18,13 @@ c
       integer*4		tileinit
       real*4		ray3(250)
       real*4		utmray(60,80), georay(60,80)
+      real*4		utmray1010(10,10)
       real*4		utmhght(80)
       real*4		hghtinit
       real*8		utmtmeray(4800)
       real*8		tmeinit
       real*4		utmcnt, geocnt
-      real*4		fillvalue, ifillv
+      real*4		fillvalue, ifillv, fillvalue0
       real*4		raycnt, ray3cnt
       real*4		tempray(60,80)
       real*4		datbuf(4800)
@@ -132,6 +133,7 @@ c
       compparm(4) = 0
       compparm(5) = 0
       fillvalue = 1996.0
+      fillvalue0 = 0.0
       raycnt = -799.0
       ray3cnt = -19.5
       attr(1) = 11
@@ -171,14 +173,23 @@ c
 c This section of the program just fills some arrays with data that we will
 c use later in the program
 c
-      do 70 index1=1,60
-         do 80 index2=1,80
+      do 70 index1=1,80
+      utmcnt=-799.00
+      geocnt=2001.00
+         do 80 index2=1,60
             utmray(index2,index1) = utmcnt
             georay(index2,index1) = geocnt
-            utmcnt = utmcnt + .4
-            geocnt = geocnt + .2
+            utmcnt = utmcnt + .400000 *index1
+            geocnt = geocnt + .200000 *index1
    80   continue
    70 continue
+        do 700 index1=1,10
+      utmcnt=-799.00
+         do 800 index2=1,10
+            utmray1010(index2,index1) = utmcnt
+             utmcnt = utmcnt + .400000 *index1
+ 800     continue
+ 700  continue
   
       
       do 30 index1=1,250
@@ -218,7 +229,7 @@ c
   240 format('***********Passed Test*********')
 
 
-      open(unit=10, file='testgridf.txt', status = "NEW")
+      open(unit=10, file='testgrid_f.txtout', status = "NEW")
 
       write(*,*)'Testing Grid FORTRAN 77 interface '
       write(*,*)'=================================='
@@ -1012,6 +1023,12 @@ c
       write(*,*)'Testing gdsetfill... '
       write(*,*)'=================='
 
+      status = gdsetfill(gdid_utm, 'Voltage', fillvalue0)
+      status = gdsetfill(gdid_utm, 'Impedance', fillvalue0)
+      status = gdsetfill(gdid_utm, 'Grounding', fillvalue0)
+
+
+
       status = gdsetfill(gdid_utm, 'Drift', fillvalue)
       if(status .lt. zero) then
          write(*,230)
@@ -1110,7 +1127,7 @@ c
       start(2) = 10
       edge(1) = 10
       edge(2) = 10
-      status = gdwrfld(gdid_utm, 'Drift', start,stride,edge,utmray)
+      status = gdwrfld(gdid_utm, 'Drift', start,stride,edge,utmray1010)
       if (status .lt. zero) then
          write(*,230)
          write(10,230)
