@@ -91,7 +91,7 @@ c
 
       zero = 0
 
-      open(unit=3, file='testpointf.txt', status = 'NEW')
+      open(unit=3, file='testpoint_f.txtout', status = 'NEW')
  
       write(*,*)'Testing Point FORTRAN 77 interface'
       write(*,*)'=================================='
