@@ -45,7 +45,7 @@ c
       equivalence(timeptr, twodtime)
       real*8 tmcnt,starttime, endtime
 
-      character idxdimmap(72)
+      character idxdimmap(39)
       character*(72) dimmap, dimname, fieldlist, dimens
 
       integer DFACC_CREATE
@@ -192,7 +192,7 @@ c
   170 continue
 
 
-      open(unit=1, file="testswathf.txt", status = "NEW")
+      open(unit=1, file="testswath_f.txtout", status = "NEW")
 
       write(*,*)'Testing Swath FORTRAN 77 interface'
       write(*,*)'=================================='
@@ -642,7 +642,7 @@ c
      1iedge, idxlat)'
       write(*,*)'Value returned by swwrfld ',status
       write(1,*)'status=swwrfld(swid2, "Latitude", istart, stride,       &
-     1iedge, lat)'
+     1iedge, idxlat)'
       write(1,*)'Value returned by swwrfld ',status
       write(*,*)' '
       write(1,*)' '
@@ -725,10 +725,10 @@ c
 
       sds1_id=sfcreate(sd_id, "DataOne", DFNT_FLOAT32, rank,dimsizes)
       write(*,*)'sds1_id=sfcreate(sd_id, "DataOne", DFNT_FLOAT32,        &
-     1rank,dimsizes)'
+     1rank, dimsizes)'
       write(*,*)'Value returned by sfcreate ',sds1_id
       write(1,*)'sds1_id=sfcreate(sd_id, "DataOne", DFNT_FLOAT32,        &
-     1rank,dimsizes)'
+     1rank, dimsizes)'
       write(1,*)'Value returned by sfcreate ',sds1_id
       write(*,*)' '
       write(1,*)' '
@@ -1023,7 +1023,7 @@ c
       write(*,*)'Number of dimesions ',ndims
       write(*,*)'Names of dimensions ',dimname
       write(*,*)'Size of dimensions ',dims
-      write(1,*)'ndims=swinqdims(swid, dimname, dims)'
+      write(1,*)'ndims=swinqdims(swid2, dimname, dims)'
       write(1,*)'Number of dimesions ',ndims
       write(1,*)'Names of dimensions ',dimname
       write(1,*)'Size of dimensions ',dims
@@ -1173,6 +1173,7 @@ c
       write(1,*)'status4=swimapinfo(swid2, "GeoXtrack", "DataXtrack",    &
      1idxmap)'
       write(1,*)'Value returned by swimapinfo ',status4
+      write(*,*)'Indexed map values ',idxmap
       write(1,*)'Indexed map values ',idxmap
       write(*,*)' '
       write(1,*)' '
